@@ -54,43 +54,50 @@
 #' library(stars)
 #' library(itsdm)
 #'
+#' # Prepare data
 #' data("occ_virtual_species")
-#' occ_virtual_species <- occ_virtual_species %>%
-#'   mutate(id = row_number())
+#' obs_df <- occ_virtual_species %>% filter(usage == "train")
+#' eval_df <- occ_virtual_species %>% filter(usage == "eval")
+#' x_col <- "x"
+#' y_col <- "y"
+#' obs_col <- "observation"
 #'
-#' set.seed(11)
-#' occ <- occ_virtual_species %>% sample_frac(0.7)
-#' occ_test <- occ_virtual_species %>% filter(! id %in% occ$id)
-#' occ <- occ %>% select(-id)
-#' occ_test <- occ_test %>% select(-id)
+#' # Format the observations
+#' obs_train_eval <- format_observation(
+#'   obs_df = obs_df, eval_df = eval_df,
+#'   x_col = x_col, y_col = y_col, obs_col = obs_col,
+#'   obs_type = "presence_only")
 #'
 #' env_vars <- system.file(
 #'   'extdata/bioclim_tanzania_10min.tif',
 #'   package = 'itsdm') %>% read_stars() %>%
 #'   slice('band', c(1, 5, 12, 16))
 #'
+#' # With imperfect_presence mode,
 #' mod <- isotree_po(
-#'   occ = occ, occ_test = occ_test,
-#'   variables = env_vars, ntrees = 50,
-#'   sample_size = 0.8, ndim = 3L,
+#'   obs_mode = "imperfect_presence",
+#'   obs = obs_train_eval$obs,
+#'   obs_ind_eval = obs_train_eval$eval,
+#'   variables = env_vars, ntrees = 20,
+#'   sample_size = 0.8, ndim = 2L,
 #'   seed = 123L, response = FALSE,
 #'   spatial_response = FALSE,
 #'   check_variable = FALSE)
 #'
 #' # Threshold conversion
 #' pa_thred <- convert_to_pa(mod$prediction,
-#'   method = 'threshold', beta = 0.5)
+#'                           method = 'threshold', beta = 0.5, visualize = FALSE)
 #' pa_thred
 #' plot(pa_thred)
 #'
 #' # Logistic conversion
 #' pa_log <- convert_to_pa(mod$prediction, method = 'logistic',
-#'   beta = 0.5, alpha = -.05)
+#'                         beta = 0.5, alpha = -.05)
 #'
 #' # Linear conversion
 #' pa_lin <- convert_to_pa(mod$prediction, method = 'linear',
-#'   a = 1, b = 0)
-#'
+#'                         a = 1, b = 0)
+#' #'
 convert_to_pa <- function(suitability, # prediction from isotree_sdm
                           method = "logistic",
                           beta = 0.5, # could be NA, for threshold or logistic
@@ -378,7 +385,9 @@ convert_to_pa <- function(suitability, # prediction from isotree_sdm
               pa_map = pa_map)
   class(out) <- append("PAConversion", class(out))
 
-  if (visualize) plot(out)
+  if (visualize) {
+    print(plot(out))
+  }
   # Return
   return(out)
 }
